Class: PulpRpmClient::PatchedrpmRpmRepository

Inherits:
Object
  • Object
show all
Defined in:
lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb

Overview

Serializer for Rpm Repositories.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PatchedrpmRpmRepository

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 157

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PulpRpmClient::PatchedrpmRpmRepository` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PulpRpmClient::PatchedrpmRpmRepository`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pulp_labels')
    if (value = attributes[:'pulp_labels']).is_a?(Hash)
      self.pulp_labels = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'retain_repo_versions')
    self.retain_repo_versions = attributes[:'retain_repo_versions']
  end

  if attributes.key?(:'retain_checkpoints')
    self.retain_checkpoints = attributes[:'retain_checkpoints']
  end

  if attributes.key?(:'remote')
    self.remote = attributes[:'remote']
  end

  if attributes.key?(:'autopublish')
    self.autopublish = attributes[:'autopublish']
  else
    self.autopublish = false
  end

  if attributes.key?(:'metadata_signing_service')
    self. = attributes[:'metadata_signing_service']
  end

  if attributes.key?(:'package_signing_service')
    self.package_signing_service = attributes[:'package_signing_service']
  end

  if attributes.key?(:'package_signing_fingerprint')
    self.package_signing_fingerprint = attributes[:'package_signing_fingerprint']
  end

  if attributes.key?(:'retain_package_versions')
    self.retain_package_versions = attributes[:'retain_package_versions']
  end

  if attributes.key?(:'checksum_type')
    self.checksum_type = attributes[:'checksum_type']
  end

  if attributes.key?(:'repo_config')
    self.repo_config = attributes[:'repo_config']
  end

  if attributes.key?(:'compression_type')
    self.compression_type = attributes[:'compression_type']
  end

  if attributes.key?(:'layout')
    self.layout = attributes[:'layout']
  end

  if attributes.key?(:'osv_config')
    if (value = attributes[:'osv_config']).is_a?(Array)
      self.osv_config = value
    end
  end
end

Instance Attribute Details

#autopublishObject

Whether to automatically create publications for new repository versions, and update any distributions pointing to this repository.



37
38
39
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 37

def autopublish
  @autopublish
end

#checksum_typeObject

The preferred checksum type during repo publish. * unknown - unknown * md5 - md5 * sha1 - sha1 * sha224 - sha224 * sha256 - sha256 * sha384 - sha384 * sha512 - sha512



52
53
54
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 52

def checksum_type
  @checksum_type
end

#compression_typeObject

The compression type to use for metadata files. * zstd - zstd * gz - gz * none - none



58
59
60
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 58

def compression_type
  @compression_type
end

#descriptionObject

An optional description.



25
26
27
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 25

def description
  @description
end

#layoutObject

How to layout the packages within the published repository. * nested_alphabetically - nested_alphabetically * flat - flat * nested_by_digest - nested_by_digest



61
62
63
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 61

def layout
  @layout
end

#metadata_signing_serviceObject

A reference to an associated signing service.



40
41
42
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 40

def 
  @metadata_signing_service
end

#nameObject

A unique name for this repository.



22
23
24
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 22

def name
  @name
end

#osv_configObject

OSV vulnerability scanning configuration. A JSON list of ecosystem entries, each with a 'name' and required 'releases' field. See vulnerability-report for supported ecosystems and release formats.



64
65
66
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 64

def osv_config
  @osv_config
end

#package_signing_fingerprintObject

The pubkey fingerprint to be passed to the package signing service. Format: 'v:' or 'keyid:<16-hex-char>'. Example: 'v4:ABCDEF1234567890ABCDEF1234567890ABCDEF12'.



46
47
48
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 46

def package_signing_fingerprint
  @package_signing_fingerprint
end

#package_signing_serviceObject

A reference to an associated package signing service.



43
44
45
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 43

def package_signing_service
  @package_signing_service
end

#pulp_labelsObject

Returns the value of attribute pulp_labels.



19
20
21
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 19

def pulp_labels
  @pulp_labels
end

#remoteObject

An optional remote to use by default when syncing.



34
35
36
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 34

def remote
  @remote
end

#repo_configObject

A JSON document describing the config.repo file Pulp should generate for this repo



55
56
57
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 55

def repo_config
  @repo_config
end

#retain_checkpointsObject

Retain X checkpoint publications for the repository. Default is null which retains all checkpoints.



31
32
33
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 31

def retain_checkpoints
  @retain_checkpoints
end

#retain_package_versionsObject

The number of versions of each package to keep in the repository; older versions will be purged. The default is '0', which will disable this feature and keep all versions of each package.



49
50
51
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 49

def retain_package_versions
  @retain_package_versions
end

#retain_repo_versionsObject

Retain X versions of the repository. Default is null which retains all versions.



28
29
30
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 28

def retain_repo_versions
  @retain_repo_versions
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 425

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PulpRpmClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



111
112
113
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 111

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 89

def self.attribute_map
  {
    :'pulp_labels' => :'pulp_labels',
    :'name' => :'name',
    :'description' => :'description',
    :'retain_repo_versions' => :'retain_repo_versions',
    :'retain_checkpoints' => :'retain_checkpoints',
    :'remote' => :'remote',
    :'autopublish' => :'autopublish',
    :'metadata_signing_service' => :'metadata_signing_service',
    :'package_signing_service' => :'package_signing_service',
    :'package_signing_fingerprint' => :'package_signing_fingerprint',
    :'retain_package_versions' => :'retain_package_versions',
    :'checksum_type' => :'checksum_type',
    :'repo_config' => :'repo_config',
    :'compression_type' => :'compression_type',
    :'layout' => :'layout',
    :'osv_config' => :'osv_config'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 401

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 138

def self.openapi_nullable
  Set.new([
    :'description',
    :'retain_repo_versions',
    :'retain_checkpoints',
    :'remote',
    :'metadata_signing_service',
    :'package_signing_service',
    :'package_signing_fingerprint',
    :'checksum_type',
    :'repo_config',
    :'compression_type',
    :'layout',
    :'osv_config'
  ])
end

.openapi_typesObject

Attribute type mapping.



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 116

def self.openapi_types
  {
    :'pulp_labels' => :'Hash<String, String>',
    :'name' => :'String',
    :'description' => :'String',
    :'retain_repo_versions' => :'Integer',
    :'retain_checkpoints' => :'Integer',
    :'remote' => :'String',
    :'autopublish' => :'Boolean',
    :'metadata_signing_service' => :'String',
    :'package_signing_service' => :'String',
    :'package_signing_fingerprint' => :'String',
    :'retain_package_versions' => :'Integer',
    :'checksum_type' => :'PackageChecksumTypeEnum',
    :'repo_config' => :'Object',
    :'compression_type' => :'CompressionTypeEnum',
    :'layout' => :'LayoutEnum',
    :'osv_config' => :'Array<PatchedrpmRpmRepositoryOsvConfigInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 365

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pulp_labels == o.pulp_labels &&
      name == o.name &&
      description == o.description &&
      retain_repo_versions == o.retain_repo_versions &&
      retain_checkpoints == o.retain_checkpoints &&
      remote == o.remote &&
      autopublish == o.autopublish &&
       == o. &&
      package_signing_service == o.package_signing_service &&
      package_signing_fingerprint == o.package_signing_fingerprint &&
      retain_package_versions == o.retain_package_versions &&
      checksum_type == o.checksum_type &&
      repo_config == o.repo_config &&
      compression_type == o.compression_type &&
      layout == o.layout &&
      osv_config == o.osv_config
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



496
497
498
499
500
501
502
503
504
505
506
507
508
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 496

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


388
389
390
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 388

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



394
395
396
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 394

def hash
  [pulp_labels, name, description, retain_repo_versions, retain_checkpoints, remote, autopublish, , package_signing_service, package_signing_fingerprint, retain_package_versions, checksum_type, repo_config, compression_type, layout, osv_config].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 243

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.')
  end

  if !@description.nil? && @description.to_s.length < 1
    invalid_properties.push('invalid value for "description", the character length must be great than or equal to 1.')
  end

  if !@retain_repo_versions.nil? && @retain_repo_versions < 1
    invalid_properties.push('invalid value for "retain_repo_versions", must be greater than or equal to 1.')
  end

  if !@retain_checkpoints.nil? && @retain_checkpoints < 1
    invalid_properties.push('invalid value for "retain_checkpoints", must be greater than or equal to 1.')
  end

  if !@package_signing_fingerprint.nil? && @package_signing_fingerprint.to_s.length > 68
    invalid_properties.push('invalid value for "package_signing_fingerprint", the character length must be smaller than or equal to 68.')
  end

  if !@package_signing_fingerprint.nil? && @package_signing_fingerprint.to_s.length < 1
    invalid_properties.push('invalid value for "package_signing_fingerprint", the character length must be great than or equal to 1.')
  end

  if !@retain_package_versions.nil? && @retain_package_versions < 0
    invalid_properties.push('invalid value for "retain_package_versions", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



472
473
474
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 472

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



478
479
480
481
482
483
484
485
486
487
488
489
490
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 478

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



466
467
468
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 466

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



279
280
281
282
283
284
285
286
287
288
289
# File 'lib/pulp_rpm_client/models/patchedrpm_rpm_repository.rb', line 279

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@name.nil? && @name.to_s.length < 1
  return false if !@description.nil? && @description.to_s.length < 1
  return false if !@retain_repo_versions.nil? && @retain_repo_versions < 1
  return false if !@retain_checkpoints.nil? && @retain_checkpoints < 1
  return false if !@package_signing_fingerprint.nil? && @package_signing_fingerprint.to_s.length > 68
  return false if !@package_signing_fingerprint.nil? && @package_signing_fingerprint.to_s.length < 1
  return false if !@retain_package_versions.nil? && @retain_package_versions < 0
  true
end