Class: PulpRpmClient::RpmModulemd

Inherits:
Object
  • Object
show all
Defined in:
lib/pulp_rpm_client/models/rpm_modulemd.rb

Overview

Modulemd serializer.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RpmModulemd

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 122

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PulpRpmClient::RpmModulemd` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PulpRpmClient::RpmModulemd`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'repository')
    self.repository = attributes[:'repository']
  end

  if attributes.key?(:'overwrite')
    self.overwrite = attributes[:'overwrite']
  end

  if attributes.key?(:'pulp_labels')
    if (value = attributes[:'pulp_labels']).is_a?(Hash)
      self.pulp_labels = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'stream')
    self.stream = attributes[:'stream']
  else
    self.stream = nil
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  else
    self.version = nil
  end

  if attributes.key?(:'static_context')
    self.static_context = attributes[:'static_context']
  end

  if attributes.key?(:'context')
    self.context = attributes[:'context']
  else
    self.context = nil
  end

  if attributes.key?(:'arch')
    self.arch = attributes[:'arch']
  else
    self.arch = nil
  end

  if attributes.key?(:'artifacts')
    self.artifacts = attributes[:'artifacts']
  else
    self.artifacts = nil
  end

  if attributes.key?(:'dependencies')
    self.dependencies = attributes[:'dependencies']
  else
    self.dependencies = nil
  end

  if attributes.key?(:'packages')
    if (value = attributes[:'packages']).is_a?(Array)
      self.packages = value
    end
  end

  if attributes.key?(:'snippet')
    self.snippet = attributes[:'snippet']
  else
    self.snippet = nil
  end

  if attributes.key?(:'profiles')
    self.profiles = attributes[:'profiles']
  else
    self.profiles = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end
end

Instance Attribute Details

#archObject

Modulemd architecture.



44
45
46
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 44

def arch
  @arch
end

#artifactsObject

Modulemd artifacts.



47
48
49
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 47

def artifacts
  @artifacts
end

#contextObject

Modulemd context.



41
42
43
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 41

def context
  @context
end

#dependenciesObject

Modulemd dependencies.



50
51
52
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 50

def dependencies
  @dependencies
end

#descriptionObject

Description of module.



62
63
64
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 62

def description
  @description
end

#nameObject

Modulemd name.



29
30
31
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 29

def name
  @name
end

#overwriteObject

When set to true, existing content in the repository with the same unique key will be silently overwritten. When set to false, the task will fail if content would be overwritten. Only used when ‘repository’ is specified. Defaults to true.



23
24
25
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 23

def overwrite
  @overwrite
end

#packagesObject

Modulemd artifacts’ packages.



53
54
55
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 53

def packages
  @packages
end

#profilesObject

Modulemd profiles.



59
60
61
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 59

def profiles
  @profiles
end

#pulp_labelsObject

A dictionary of arbitrary key/value pairs used to describe a specific Content instance.



26
27
28
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 26

def pulp_labels
  @pulp_labels
end

#repositoryObject

A URI of a repository the new content unit should be associated with.



20
21
22
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 20

def repository
  @repository
end

#snippetObject

Modulemd snippet



56
57
58
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 56

def snippet
  @snippet
end

#static_contextObject

Modulemd static-context flag.



38
39
40
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 38

def static_context
  @static_context
end

#streamObject

Stream name.



32
33
34
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 32

def stream
  @stream
end

#versionObject

Modulemd version.



35
36
37
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 35

def version
  @version
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 464

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PulpRpmClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 86

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 65

def self.attribute_map
  {
    :'repository' => :'repository',
    :'overwrite' => :'overwrite',
    :'pulp_labels' => :'pulp_labels',
    :'name' => :'name',
    :'stream' => :'stream',
    :'version' => :'version',
    :'static_context' => :'static_context',
    :'context' => :'context',
    :'arch' => :'arch',
    :'artifacts' => :'artifacts',
    :'dependencies' => :'dependencies',
    :'packages' => :'packages',
    :'snippet' => :'snippet',
    :'profiles' => :'profiles',
    :'description' => :'description'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 440

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
116
117
118
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 112

def self.openapi_nullable
  Set.new([
    :'artifacts',
    :'dependencies',
    :'profiles',
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 91

def self.openapi_types
  {
    :'repository' => :'String',
    :'overwrite' => :'Boolean',
    :'pulp_labels' => :'Hash<String, String>',
    :'name' => :'String',
    :'stream' => :'String',
    :'version' => :'String',
    :'static_context' => :'Boolean',
    :'context' => :'String',
    :'arch' => :'String',
    :'artifacts' => :'Object',
    :'dependencies' => :'Object',
    :'packages' => :'Array<String>',
    :'snippet' => :'String',
    :'profiles' => :'Object',
    :'description' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 405

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      repository == o.repository &&
      overwrite == o.overwrite &&
      pulp_labels == o.pulp_labels &&
      name == o.name &&
      stream == o.stream &&
      version == o.version &&
      static_context == o.static_context &&
      context == o.context &&
      arch == o.arch &&
      artifacts == o.artifacts &&
      dependencies == o.dependencies &&
      packages == o.packages &&
      snippet == o.snippet &&
      profiles == o.profiles &&
      description == o.description
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 535

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


427
428
429
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 427

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



433
434
435
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 433

def hash
  [repository, overwrite, pulp_labels, name, stream, version, static_context, context, arch, artifacts, dependencies, packages, snippet, profiles, description].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 222

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.')
  end

  if @stream.nil?
    invalid_properties.push('invalid value for "stream", stream cannot be nil.')
  end

  if @stream.to_s.length < 1
    invalid_properties.push('invalid value for "stream", the character length must be great than or equal to 1.')
  end

  if @version.nil?
    invalid_properties.push('invalid value for "version", version cannot be nil.')
  end

  if @version.to_s.length < 1
    invalid_properties.push('invalid value for "version", the character length must be great than or equal to 1.')
  end

  if @context.nil?
    invalid_properties.push('invalid value for "context", context cannot be nil.')
  end

  if @context.to_s.length < 1
    invalid_properties.push('invalid value for "context", the character length must be great than or equal to 1.')
  end

  if @arch.nil?
    invalid_properties.push('invalid value for "arch", arch cannot be nil.')
  end

  if @arch.to_s.length < 1
    invalid_properties.push('invalid value for "arch", the character length must be great than or equal to 1.')
  end

  if @snippet.nil?
    invalid_properties.push('invalid value for "snippet", snippet cannot be nil.')
  end

  if @snippet.to_s.length < 1
    invalid_properties.push('invalid value for "snippet", the character length must be great than or equal to 1.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @description.to_s.length < 1
    invalid_properties.push('invalid value for "description", the character length must be great than or equal to 1.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



511
512
513
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 511

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



517
518
519
520
521
522
523
524
525
526
527
528
529
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 517

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



505
506
507
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 505

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/pulp_rpm_client/models/rpm_modulemd.rb', line 286

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @stream.nil?
  return false if @stream.to_s.length < 1
  return false if @version.nil?
  return false if @version.to_s.length < 1
  return false if @context.nil?
  return false if @context.to_s.length < 1
  return false if @arch.nil?
  return false if @arch.to_s.length < 1
  return false if @snippet.nil?
  return false if @snippet.to_s.length < 1
  return false if @description.nil?
  return false if @description.to_s.length < 1
  true
end