Class: PulpRpmClient::RpmModulemdObsolete

Inherits:
Object
  • Object
show all
Defined in:
lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb

Overview

ModulemdObsolete serializer.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RpmModulemdObsolete

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PulpRpmClient::RpmModulemdObsolete` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PulpRpmClient::RpmModulemdObsolete`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'repository')
    self.repository = attributes[:'repository']
  end

  if attributes.key?(:'overwrite')
    self.overwrite = attributes[:'overwrite']
  end

  if attributes.key?(:'pulp_labels')
    if (value = attributes[:'pulp_labels']).is_a?(Hash)
      self.pulp_labels = value
    end
  end

  if attributes.key?(:'modified')
    self.modified = attributes[:'modified']
  else
    self.modified = nil
  end

  if attributes.key?(:'module_name')
    self.module_name = attributes[:'module_name']
  else
    self.module_name = nil
  end

  if attributes.key?(:'module_stream')
    self.module_stream = attributes[:'module_stream']
  else
    self.module_stream = nil
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  else
    self.message = nil
  end

  if attributes.key?(:'override_previous')
    self.override_previous = attributes[:'override_previous']
  else
    self.override_previous = nil
  end

  if attributes.key?(:'module_context')
    self.module_context = attributes[:'module_context']
  else
    self.module_context = nil
  end

  if attributes.key?(:'eol_date')
    self.eol_date = attributes[:'eol_date']
  else
    self.eol_date = nil
  end

  if attributes.key?(:'obsoleted_by_module_name')
    self.obsoleted_by_module_name = attributes[:'obsoleted_by_module_name']
  else
    self.obsoleted_by_module_name = nil
  end

  if attributes.key?(:'obsoleted_by_module_stream')
    self.obsoleted_by_module_stream = attributes[:'obsoleted_by_module_stream']
  else
    self.obsoleted_by_module_stream = nil
  end

  if attributes.key?(:'snippet')
    self.snippet = attributes[:'snippet']
  else
    self.snippet = nil
  end
end

Instance Attribute Details

#eol_dateObject

End of Life date.



47
48
49
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 47

def eol_date
  @eol_date
end

#messageObject

Obsolete description.



38
39
40
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 38

def message
  @message
end

#modifiedObject

Obsolete modified time.



29
30
31
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 29

def modified
  @modified
end

#module_contextObject

Modulemd’s context.



44
45
46
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 44

def module_context
  @module_context
end

#module_nameObject

Modulemd name.



32
33
34
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 32

def module_name
  @module_name
end

#module_streamObject

Modulemd’s stream.



35
36
37
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 35

def module_stream
  @module_stream
end

#obsoleted_by_module_nameObject

Obsolete by module name.



50
51
52
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 50

def obsoleted_by_module_name
  @obsoleted_by_module_name
end

#obsoleted_by_module_streamObject

Obsolete by module stream.



53
54
55
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 53

def obsoleted_by_module_stream
  @obsoleted_by_module_stream
end

#override_previousObject

Reset previous obsoletes.



41
42
43
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 41

def override_previous
  @override_previous
end

#overwriteObject

When set to true, existing content in the repository with the same unique key will be silently overwritten. When set to false, the task will fail if content would be overwritten. Only used when ‘repository’ is specified. Defaults to true.



23
24
25
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 23

def overwrite
  @overwrite
end

#pulp_labelsObject

A dictionary of arbitrary key/value pairs used to describe a specific Content instance.



26
27
28
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 26

def pulp_labels
  @pulp_labels
end

#repositoryObject

A URI of a repository the new content unit should be associated with.



20
21
22
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 20

def repository
  @repository
end

#snippetObject

Module Obsolete snippet.



56
57
58
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 56

def snippet
  @snippet
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 471

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PulpRpmClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 78

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 59

def self.attribute_map
  {
    :'repository' => :'repository',
    :'overwrite' => :'overwrite',
    :'pulp_labels' => :'pulp_labels',
    :'modified' => :'modified',
    :'module_name' => :'module_name',
    :'module_stream' => :'module_stream',
    :'message' => :'message',
    :'override_previous' => :'override_previous',
    :'module_context' => :'module_context',
    :'eol_date' => :'eol_date',
    :'obsoleted_by_module_name' => :'obsoleted_by_module_name',
    :'obsoleted_by_module_stream' => :'obsoleted_by_module_stream',
    :'snippet' => :'snippet'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 447

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
106
107
108
109
110
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 102

def self.openapi_nullable
  Set.new([
    :'override_previous',
    :'module_context',
    :'eol_date',
    :'obsoleted_by_module_name',
    :'obsoleted_by_module_stream',
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 83

def self.openapi_types
  {
    :'repository' => :'String',
    :'overwrite' => :'Boolean',
    :'pulp_labels' => :'Hash<String, String>',
    :'modified' => :'String',
    :'module_name' => :'String',
    :'module_stream' => :'String',
    :'message' => :'String',
    :'override_previous' => :'String',
    :'module_context' => :'String',
    :'eol_date' => :'String',
    :'obsoleted_by_module_name' => :'String',
    :'obsoleted_by_module_stream' => :'String',
    :'snippet' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 414

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      repository == o.repository &&
      overwrite == o.overwrite &&
      pulp_labels == o.pulp_labels &&
      modified == o.modified &&
      module_name == o.module_name &&
      module_stream == o.module_stream &&
      message == o.message &&
      override_previous == o.override_previous &&
      module_context == o.module_context &&
      eol_date == o.eol_date &&
      obsoleted_by_module_name == o.obsoleted_by_module_name &&
      obsoleted_by_module_stream == o.obsoleted_by_module_stream &&
      snippet == o.snippet
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



542
543
544
545
546
547
548
549
550
551
552
553
554
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 542

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


434
435
436
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 434

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



440
441
442
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 440

def hash
  [repository, overwrite, pulp_labels, modified, module_name, module_stream, message, override_previous, module_context, eol_date, obsoleted_by_module_name, obsoleted_by_module_stream, snippet].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 204

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @modified.nil?
    invalid_properties.push('invalid value for "modified", modified cannot be nil.')
  end

  if @modified.to_s.length < 1
    invalid_properties.push('invalid value for "modified", the character length must be great than or equal to 1.')
  end

  if @module_name.nil?
    invalid_properties.push('invalid value for "module_name", module_name cannot be nil.')
  end

  if @module_name.to_s.length < 1
    invalid_properties.push('invalid value for "module_name", the character length must be great than or equal to 1.')
  end

  if @module_stream.nil?
    invalid_properties.push('invalid value for "module_stream", module_stream cannot be nil.')
  end

  if @module_stream.to_s.length < 1
    invalid_properties.push('invalid value for "module_stream", the character length must be great than or equal to 1.')
  end

  if @message.nil?
    invalid_properties.push('invalid value for "message", message cannot be nil.')
  end

  if @message.to_s.length < 1
    invalid_properties.push('invalid value for "message", the character length must be great than or equal to 1.')
  end

  if @override_previous.to_s.length < 1
    invalid_properties.push('invalid value for "override_previous", the character length must be great than or equal to 1.')
  end

  if @module_context.to_s.length < 1
    invalid_properties.push('invalid value for "module_context", the character length must be great than or equal to 1.')
  end

  if @eol_date.to_s.length < 1
    invalid_properties.push('invalid value for "eol_date", the character length must be great than or equal to 1.')
  end

  if @obsoleted_by_module_name.to_s.length < 1
    invalid_properties.push('invalid value for "obsoleted_by_module_name", the character length must be great than or equal to 1.')
  end

  if @obsoleted_by_module_stream.to_s.length < 1
    invalid_properties.push('invalid value for "obsoleted_by_module_stream", the character length must be great than or equal to 1.')
  end

  if @snippet.nil?
    invalid_properties.push('invalid value for "snippet", snippet cannot be nil.')
  end

  if @snippet.to_s.length < 1
    invalid_properties.push('invalid value for "snippet", the character length must be great than or equal to 1.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



518
519
520
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 518

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



524
525
526
527
528
529
530
531
532
533
534
535
536
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 524

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



512
513
514
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 512

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/pulp_rpm_client/models/rpm_modulemd_obsolete.rb', line 272

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @modified.nil?
  return false if @modified.to_s.length < 1
  return false if @module_name.nil?
  return false if @module_name.to_s.length < 1
  return false if @module_stream.nil?
  return false if @module_stream.to_s.length < 1
  return false if @message.nil?
  return false if @message.to_s.length < 1
  return false if @override_previous.to_s.length < 1
  return false if @module_context.to_s.length < 1
  return false if @eol_date.to_s.length < 1
  return false if @obsoleted_by_module_name.to_s.length < 1
  return false if @obsoleted_by_module_stream.to_s.length < 1
  return false if @snippet.nil?
  return false if @snippet.to_s.length < 1
  true
end