Class: PulpRpmClient::RpmRpmDistributionResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb

Overview

Serializer for RPM Distributions.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RpmRpmDistributionResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 130

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PulpRpmClient::RpmRpmDistributionResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PulpRpmClient::RpmRpmDistributionResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pulp_href')
    self.pulp_href = attributes[:'pulp_href']
  end

  if attributes.key?(:'prn')
    self.prn = attributes[:'prn']
  end

  if attributes.key?(:'pulp_created')
    self.pulp_created = attributes[:'pulp_created']
  end

  if attributes.key?(:'pulp_last_updated')
    self.pulp_last_updated = attributes[:'pulp_last_updated']
  end

  if attributes.key?(:'base_path')
    self.base_path = attributes[:'base_path']
  else
    self.base_path = nil
  end

  if attributes.key?(:'base_url')
    self.base_url = attributes[:'base_url']
  end

  if attributes.key?(:'content_guard')
    self.content_guard = attributes[:'content_guard']
  end

  if attributes.key?(:'content_guard_prn')
    self.content_guard_prn = attributes[:'content_guard_prn']
  end

  if attributes.key?(:'no_content_change_since')
    self.no_content_change_since = attributes[:'no_content_change_since']
  end

  if attributes.key?(:'hidden')
    self.hidden = attributes[:'hidden']
  else
    self.hidden = false
  end

  if attributes.key?(:'pulp_labels')
    if (value = attributes[:'pulp_labels']).is_a?(Hash)
      self.pulp_labels = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'repository')
    self.repository = attributes[:'repository']
  end

  if attributes.key?(:'repository_version')
    self.repository_version = attributes[:'repository_version']
  end

  if attributes.key?(:'publication')
    self.publication = attributes[:'publication']
  end

  if attributes.key?(:'generate_repo_config')
    self.generate_repo_config = attributes[:'generate_repo_config']
  else
    self.generate_repo_config = false
  end

  if attributes.key?(:'checkpoint')
    self.checkpoint = attributes[:'checkpoint']
  end
end

Instance Attribute Details

#base_pathObject

The base (relative) path component of the published url. Avoid paths that overlap with other distribution base paths (e.g. "foo" and "foo/bar")



31
32
33
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 31

def base_path
  @base_path
end

#base_urlObject

The URL for accessing the publication as defined by this distribution.



34
35
36
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 34

def base_url
  @base_url
end

#checkpointObject

Returns the value of attribute checkpoint.



65
66
67
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 65

def checkpoint
  @checkpoint
end

#content_guardObject

An optional content-guard.



37
38
39
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 37

def content_guard
  @content_guard
end

#content_guard_prnObject

The Pulp Resource Name (PRN) of the associated optional content guard.



40
41
42
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 40

def content_guard_prn
  @content_guard_prn
end

#generate_repo_configObject

An option specifying whether Pulp should generate *.repo files.



63
64
65
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 63

def generate_repo_config
  @generate_repo_config
end

#hiddenObject

Whether this distribution should be shown in the content app.



46
47
48
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 46

def hidden
  @hidden
end

#nameObject

A unique name. Ex, ‘rawhide` and `stable`.



51
52
53
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 51

def name
  @name
end

#no_content_change_sinceObject

Timestamp since when the distributed content served by this distribution has not changed. If equals to ‘null`, no guarantee is provided about content changes.



43
44
45
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 43

def no_content_change_since
  @no_content_change_since
end

#prnObject

The Pulp Resource Name (PRN).



22
23
24
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 22

def prn
  @prn
end

#publicationObject

Publication to be served



60
61
62
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 60

def publication
  @publication
end

#pulp_createdObject

Timestamp of creation.



25
26
27
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 25

def pulp_created
  @pulp_created
end

#pulp_hrefObject

Returns the value of attribute pulp_href.



19
20
21
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 19

def pulp_href
  @pulp_href
end

#pulp_labelsObject

Returns the value of attribute pulp_labels.



48
49
50
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 48

def pulp_labels
  @pulp_labels
end

#pulp_last_updatedObject

Timestamp of the last time this resource was updated. Note: for immutable resources - like content, repository versions, and publication - pulp_created and pulp_last_updated dates will be the same.



28
29
30
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 28

def pulp_last_updated
  @pulp_last_updated
end

#repositoryObject

The latest RepositoryVersion for this Repository will be served.



54
55
56
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 54

def repository
  @repository
end

#repository_versionObject

RepositoryVersion to be served



57
58
59
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 57

def repository_version
  @repository_version
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 310

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PulpRpmClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 91

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 68

def self.attribute_map
  {
    :'pulp_href' => :'pulp_href',
    :'prn' => :'prn',
    :'pulp_created' => :'pulp_created',
    :'pulp_last_updated' => :'pulp_last_updated',
    :'base_path' => :'base_path',
    :'base_url' => :'base_url',
    :'content_guard' => :'content_guard',
    :'content_guard_prn' => :'content_guard_prn',
    :'no_content_change_since' => :'no_content_change_since',
    :'hidden' => :'hidden',
    :'pulp_labels' => :'pulp_labels',
    :'name' => :'name',
    :'repository' => :'repository',
    :'repository_version' => :'repository_version',
    :'publication' => :'publication',
    :'generate_repo_config' => :'generate_repo_config',
    :'checkpoint' => :'checkpoint'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 286

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



119
120
121
122
123
124
125
126
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 119

def self.openapi_nullable
  Set.new([
    :'content_guard',
    :'repository',
    :'repository_version',
    :'publication',
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 96

def self.openapi_types
  {
    :'pulp_href' => :'String',
    :'prn' => :'String',
    :'pulp_created' => :'Time',
    :'pulp_last_updated' => :'Time',
    :'base_path' => :'String',
    :'base_url' => :'String',
    :'content_guard' => :'String',
    :'content_guard_prn' => :'String',
    :'no_content_change_since' => :'String',
    :'hidden' => :'Boolean',
    :'pulp_labels' => :'Hash<String, String>',
    :'name' => :'String',
    :'repository' => :'String',
    :'repository_version' => :'String',
    :'publication' => :'String',
    :'generate_repo_config' => :'Boolean',
    :'checkpoint' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 249

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pulp_href == o.pulp_href &&
      prn == o.prn &&
      pulp_created == o.pulp_created &&
      pulp_last_updated == o.pulp_last_updated &&
      base_path == o.base_path &&
      base_url == o.base_url &&
      content_guard == o.content_guard &&
      content_guard_prn == o.content_guard_prn &&
      no_content_change_since == o.no_content_change_since &&
      hidden == o.hidden &&
      pulp_labels == o.pulp_labels &&
      name == o.name &&
      repository == o.repository &&
      repository_version == o.repository_version &&
      publication == o.publication &&
      generate_repo_config == o.generate_repo_config &&
      checkpoint == o.checkpoint
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



381
382
383
384
385
386
387
388
389
390
391
392
393
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 381

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


273
274
275
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 273

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



279
280
281
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 279

def hash
  [pulp_href, prn, pulp_created, pulp_last_updated, base_path, base_url, content_guard, content_guard_prn, no_content_change_since, hidden, pulp_labels, name, repository, repository_version, publication, generate_repo_config, checkpoint].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 224

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @base_path.nil?
    invalid_properties.push('invalid value for "base_path", base_path cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



357
358
359
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 357

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



363
364
365
366
367
368
369
370
371
372
373
374
375
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 363

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



351
352
353
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 351

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



240
241
242
243
244
245
# File 'lib/pulp_rpm_client/models/rpm_rpm_distribution_response.rb', line 240

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @base_path.nil?
  return false if @name.nil?
  true
end