Class: PulpRpmClient::RpmRpmRepository
- Inherits:
-
Object
- Object
- PulpRpmClient::RpmRpmRepository
- Defined in:
- lib/pulp_rpm_client/models/rpm_rpm_repository.rb
Overview
Serializer for Rpm Repositories.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#autopublish ⇒ Object
Whether to automatically create publications for new repository versions, and update any distributions pointing to this repository.
-
#checksum_type ⇒ Object
The preferred checksum type during repo publish.
-
#compression_type ⇒ Object
The compression type to use for metadata files.
-
#description ⇒ Object
An optional description.
-
#layout ⇒ Object
How to layout the packages within the published repository.
-
#metadata_signing_service ⇒ Object
A reference to an associated signing service.
-
#name ⇒ Object
A unique name for this repository.
-
#osv_config ⇒ Object
OSV vulnerability scanning configuration.
-
#package_signing_fingerprint ⇒ Object
The pubkey fingerprint to be passed to the package signing service.
-
#package_signing_service ⇒ Object
A reference to an associated package signing service.
-
#pulp_labels ⇒ Object
Returns the value of attribute pulp_labels.
-
#remote ⇒ Object
An optional remote to use by default when syncing.
-
#repo_config ⇒ Object
A JSON document describing the config.repo file Pulp should generate for this repo.
-
#retain_checkpoints ⇒ Object
Retain X checkpoint publications for the repository.
-
#retain_package_versions ⇒ Object
The number of versions of each package to keep in the repository; older versions will be purged.
-
#retain_repo_versions ⇒ Object
Retain X versions of the repository.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RpmRpmRepository
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RpmRpmRepository
Initializes the object
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 157 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PulpRpmClient::RpmRpmRepository` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PulpRpmClient::RpmRpmRepository`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pulp_labels') if (value = attributes[:'pulp_labels']).is_a?(Hash) self.pulp_labels = value end end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'retain_repo_versions') self.retain_repo_versions = attributes[:'retain_repo_versions'] end if attributes.key?(:'retain_checkpoints') self.retain_checkpoints = attributes[:'retain_checkpoints'] end if attributes.key?(:'remote') self.remote = attributes[:'remote'] end if attributes.key?(:'autopublish') self.autopublish = attributes[:'autopublish'] else self.autopublish = false end if attributes.key?(:'metadata_signing_service') self. = attributes[:'metadata_signing_service'] end if attributes.key?(:'package_signing_service') self.package_signing_service = attributes[:'package_signing_service'] end if attributes.key?(:'package_signing_fingerprint') self.package_signing_fingerprint = attributes[:'package_signing_fingerprint'] end if attributes.key?(:'retain_package_versions') self.retain_package_versions = attributes[:'retain_package_versions'] end if attributes.key?(:'checksum_type') self.checksum_type = attributes[:'checksum_type'] end if attributes.key?(:'repo_config') self.repo_config = attributes[:'repo_config'] end if attributes.key?(:'compression_type') self.compression_type = attributes[:'compression_type'] end if attributes.key?(:'layout') self.layout = attributes[:'layout'] end if attributes.key?(:'osv_config') if (value = attributes[:'osv_config']).is_a?(Array) self.osv_config = value end end end |
Instance Attribute Details
#autopublish ⇒ Object
Whether to automatically create publications for new repository versions, and update any distributions pointing to this repository.
37 38 39 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 37 def autopublish @autopublish end |
#checksum_type ⇒ Object
The preferred checksum type during repo publish. * unknown - unknown * md5 - md5 * sha1 - sha1 * sha224 - sha224 * sha256 - sha256 * sha384 - sha384 * sha512 - sha512
52 53 54 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 52 def checksum_type @checksum_type end |
#compression_type ⇒ Object
The compression type to use for metadata files. * zstd - zstd * gz - gz * none - none
58 59 60 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 58 def compression_type @compression_type end |
#description ⇒ Object
An optional description.
25 26 27 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 25 def description @description end |
#layout ⇒ Object
How to layout the packages within the published repository. * nested_alphabetically - nested_alphabetically * flat - flat * nested_by_digest - nested_by_digest
61 62 63 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 61 def layout @layout end |
#metadata_signing_service ⇒ Object
A reference to an associated signing service.
40 41 42 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 40 def @metadata_signing_service end |
#name ⇒ Object
A unique name for this repository.
22 23 24 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 22 def name @name end |
#osv_config ⇒ Object
OSV vulnerability scanning configuration. A JSON list of ecosystem entries, each with a 'name' and required 'releases' field. See vulnerability-report for supported ecosystems and release formats.
64 65 66 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 64 def osv_config @osv_config end |
#package_signing_fingerprint ⇒ Object
The pubkey fingerprint to be passed to the package signing service. Format: 'v
46 47 48 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 46 def package_signing_fingerprint @package_signing_fingerprint end |
#package_signing_service ⇒ Object
A reference to an associated package signing service.
43 44 45 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 43 def package_signing_service @package_signing_service end |
#pulp_labels ⇒ Object
Returns the value of attribute pulp_labels.
19 20 21 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 19 def pulp_labels @pulp_labels end |
#remote ⇒ Object
An optional remote to use by default when syncing.
34 35 36 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 34 def remote @remote end |
#repo_config ⇒ Object
A JSON document describing the config.repo file Pulp should generate for this repo
55 56 57 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 55 def repo_config @repo_config end |
#retain_checkpoints ⇒ Object
Retain X checkpoint publications for the repository. Default is null which retains all checkpoints.
31 32 33 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 31 def retain_checkpoints @retain_checkpoints end |
#retain_package_versions ⇒ Object
The number of versions of each package to keep in the repository; older versions will be purged. The default is '0', which will disable this feature and keep all versions of each package.
49 50 51 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 49 def retain_package_versions @retain_package_versions end |
#retain_repo_versions ⇒ Object
Retain X versions of the repository. Default is null which retains all versions.
28 29 30 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 28 def retain_repo_versions @retain_repo_versions end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 432 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PulpRpmClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
111 112 113 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 111 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 89 def self.attribute_map { :'pulp_labels' => :'pulp_labels', :'name' => :'name', :'description' => :'description', :'retain_repo_versions' => :'retain_repo_versions', :'retain_checkpoints' => :'retain_checkpoints', :'remote' => :'remote', :'autopublish' => :'autopublish', :'metadata_signing_service' => :'metadata_signing_service', :'package_signing_service' => :'package_signing_service', :'package_signing_fingerprint' => :'package_signing_fingerprint', :'retain_package_versions' => :'retain_package_versions', :'checksum_type' => :'checksum_type', :'repo_config' => :'repo_config', :'compression_type' => :'compression_type', :'layout' => :'layout', :'osv_config' => :'osv_config' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 408 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 138 def self.openapi_nullable Set.new([ :'description', :'retain_repo_versions', :'retain_checkpoints', :'remote', :'metadata_signing_service', :'package_signing_service', :'package_signing_fingerprint', :'checksum_type', :'repo_config', :'compression_type', :'layout', :'osv_config' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 116 def self.openapi_types { :'pulp_labels' => :'Hash<String, String>', :'name' => :'String', :'description' => :'String', :'retain_repo_versions' => :'Integer', :'retain_checkpoints' => :'Integer', :'remote' => :'String', :'autopublish' => :'Boolean', :'metadata_signing_service' => :'String', :'package_signing_service' => :'String', :'package_signing_fingerprint' => :'String', :'retain_package_versions' => :'Integer', :'checksum_type' => :'PackageChecksumTypeEnum', :'repo_config' => :'Object', :'compression_type' => :'CompressionTypeEnum', :'layout' => :'LayoutEnum', :'osv_config' => :'Array<PatchedrpmRpmRepositoryOsvConfigInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 372 def ==(o) return true if self.equal?(o) self.class == o.class && pulp_labels == o.pulp_labels && name == o.name && description == o.description && retain_repo_versions == o.retain_repo_versions && retain_checkpoints == o.retain_checkpoints && remote == o.remote && autopublish == o.autopublish && == o. && package_signing_service == o.package_signing_service && package_signing_fingerprint == o.package_signing_fingerprint && retain_package_versions == o.retain_package_versions && checksum_type == o.checksum_type && repo_config == o.repo_config && compression_type == o.compression_type && layout == o.layout && osv_config == o.osv_config end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
503 504 505 506 507 508 509 510 511 512 513 514 515 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 503 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
395 396 397 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 395 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
401 402 403 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 401 def hash [pulp_labels, name, description, retain_repo_versions, retain_checkpoints, remote, autopublish, , package_signing_service, package_signing_fingerprint, retain_package_versions, checksum_type, repo_config, compression_type, layout, osv_config].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 245 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.') end if !@description.nil? && @description.to_s.length < 1 invalid_properties.push('invalid value for "description", the character length must be great than or equal to 1.') end if !@retain_repo_versions.nil? && @retain_repo_versions < 1 invalid_properties.push('invalid value for "retain_repo_versions", must be greater than or equal to 1.') end if !@retain_checkpoints.nil? && @retain_checkpoints < 1 invalid_properties.push('invalid value for "retain_checkpoints", must be greater than or equal to 1.') end if !@package_signing_fingerprint.nil? && @package_signing_fingerprint.to_s.length > 68 invalid_properties.push('invalid value for "package_signing_fingerprint", the character length must be smaller than or equal to 68.') end if !@package_signing_fingerprint.nil? && @package_signing_fingerprint.to_s.length < 1 invalid_properties.push('invalid value for "package_signing_fingerprint", the character length must be great than or equal to 1.') end if !@retain_package_versions.nil? && @retain_package_versions < 0 invalid_properties.push('invalid value for "retain_package_versions", must be greater than or equal to 0.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
479 480 481 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 479 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
485 486 487 488 489 490 491 492 493 494 495 496 497 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 485 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
473 474 475 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 473 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository.rb', line 285 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 return false if !@description.nil? && @description.to_s.length < 1 return false if !@retain_repo_versions.nil? && @retain_repo_versions < 1 return false if !@retain_checkpoints.nil? && @retain_checkpoints < 1 return false if !@package_signing_fingerprint.nil? && @package_signing_fingerprint.to_s.length > 68 return false if !@package_signing_fingerprint.nil? && @package_signing_fingerprint.to_s.length < 1 return false if !@retain_package_versions.nil? && @retain_package_versions < 0 true end |