Class: PulpRpmClient::RpmRpmRepositoryResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb

Overview

Serializer for Rpm Repositories.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RpmRpmRepositoryResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 210

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PulpRpmClient::RpmRpmRepositoryResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PulpRpmClient::RpmRpmRepositoryResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pulp_href')
    self.pulp_href = attributes[:'pulp_href']
  end

  if attributes.key?(:'prn')
    self.prn = attributes[:'prn']
  end

  if attributes.key?(:'pulp_created')
    self.pulp_created = attributes[:'pulp_created']
  end

  if attributes.key?(:'pulp_last_updated')
    self.pulp_last_updated = attributes[:'pulp_last_updated']
  end

  if attributes.key?(:'versions_href')
    self.versions_href = attributes[:'versions_href']
  end

  if attributes.key?(:'pulp_labels')
    if (value = attributes[:'pulp_labels']).is_a?(Hash)
      self.pulp_labels = value
    end
  end

  if attributes.key?(:'latest_version_href')
    self.latest_version_href = attributes[:'latest_version_href']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'retain_repo_versions')
    self.retain_repo_versions = attributes[:'retain_repo_versions']
  end

  if attributes.key?(:'retain_checkpoints')
    self.retain_checkpoints = attributes[:'retain_checkpoints']
  end

  if attributes.key?(:'remote')
    self.remote = attributes[:'remote']
  end

  if attributes.key?(:'autopublish')
    self.autopublish = attributes[:'autopublish']
  else
    self.autopublish = false
  end

  if attributes.key?(:'metadata_signing_service')
    self. = attributes[:'metadata_signing_service']
  end

  if attributes.key?(:'package_signing_service')
    self.package_signing_service = attributes[:'package_signing_service']
  end

  if attributes.key?(:'package_signing_fingerprint')
    self.package_signing_fingerprint = attributes[:'package_signing_fingerprint']
  end

  if attributes.key?(:'retain_package_versions')
    self.retain_package_versions = attributes[:'retain_package_versions']
  end

  if attributes.key?(:'checksum_type')
    self.checksum_type = attributes[:'checksum_type']
  end

  if attributes.key?(:'metadata_checksum_type')
    self. = attributes[:'metadata_checksum_type']
  end

  if attributes.key?(:'package_checksum_type')
    self.package_checksum_type = attributes[:'package_checksum_type']
  end

  if attributes.key?(:'gpgcheck')
    self.gpgcheck = attributes[:'gpgcheck']
  end

  if attributes.key?(:'repo_gpgcheck')
    self.repo_gpgcheck = attributes[:'repo_gpgcheck']
  end

  if attributes.key?(:'sqlite_metadata')
    self. = attributes[:'sqlite_metadata']
  else
    self. = false
  end

  if attributes.key?(:'repo_config')
    self.repo_config = attributes[:'repo_config']
  end

  if attributes.key?(:'compression_type')
    self.compression_type = attributes[:'compression_type']
  end

  if attributes.key?(:'layout')
    self.layout = attributes[:'layout']
  end

  if attributes.key?(:'osv_config')
    if (value = attributes[:'osv_config']).is_a?(Array)
      self.osv_config = value
    end
  end
end

Instance Attribute Details

#autopublishObject

Whether to automatically create publications for new repository versions, and update any distributions pointing to this repository.



52
53
54
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 52

def autopublish
  @autopublish
end

#checksum_typeObject

The preferred checksum type during repo publish. * unknown - unknown * md5 - md5 * sha1 - sha1 * sha224 - sha224 * sha256 - sha256 * sha384 - sha384 * sha512 - sha512



67
68
69
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 67

def checksum_type
  @checksum_type
end

#compression_typeObject

The compression type to use for metadata files. * zstd - zstd * gz - gz * none - none



88
89
90
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 88

def compression_type
  @compression_type
end

#descriptionObject

An optional description.



40
41
42
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 40

def description
  @description
end

#gpgcheckObject

REMOVED: An option specifying whether a client should perform a GPG signature check on packages. Not operational since pulp_rpm 3.30.0 release. Set these values using 'repo_config' instead.



76
77
78
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 76

def gpgcheck
  @gpgcheck
end

#latest_version_hrefObject

Returns the value of attribute latest_version_href.



34
35
36
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 34

def latest_version_href
  @latest_version_href
end

#layoutObject

How to layout the packages within the published repository. * nested_alphabetically - nested_alphabetically * flat - flat * nested_by_digest - nested_by_digest



91
92
93
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 91

def layout
  @layout
end

#metadata_checksum_typeObject

REMOVED: The checksum type to use for metadata. Not operational since pulp_rpm 3.30.0 release. Use 'checksum_type' instead. * unknown - unknown * md5 - md5 * sha1 - sha1 * sha224 - sha224 * sha256 - sha256 * sha384 - sha384 * sha512 - sha512



70
71
72
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 70

def 
  @metadata_checksum_type
end

#metadata_signing_serviceObject

A reference to an associated signing service.



55
56
57
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 55

def 
  @metadata_signing_service
end

#nameObject

A unique name for this repository.



37
38
39
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 37

def name
  @name
end

#osv_configObject

OSV vulnerability scanning configuration. A JSON list of ecosystem entries, each with a 'name' and required 'releases' field. See vulnerability-report for supported ecosystems and release formats.



94
95
96
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 94

def osv_config
  @osv_config
end

#package_checksum_typeObject

REMOVED: The checksum type for packages. Not operational since pulp_rpm 3.30.0 release. Use 'checksum_type' instead. * unknown - unknown * md5 - md5 * sha1 - sha1 * sha224 - sha224 * sha256 - sha256 * sha384 - sha384 * sha512 - sha512



73
74
75
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 73

def package_checksum_type
  @package_checksum_type
end

#package_signing_fingerprintObject

The pubkey fingerprint to be passed to the package signing service. Format: 'v:' or 'keyid:<16-hex-char>'. Example: 'v4:ABCDEF1234567890ABCDEF1234567890ABCDEF12'.



61
62
63
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 61

def package_signing_fingerprint
  @package_signing_fingerprint
end

#package_signing_serviceObject

A reference to an associated package signing service.



58
59
60
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 58

def package_signing_service
  @package_signing_service
end

#prnObject

The Pulp Resource Name (PRN).



22
23
24
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 22

def prn
  @prn
end

#pulp_createdObject

Timestamp of creation.



25
26
27
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 25

def pulp_created
  @pulp_created
end

#pulp_hrefObject

Returns the value of attribute pulp_href.



19
20
21
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 19

def pulp_href
  @pulp_href
end

#pulp_labelsObject

Returns the value of attribute pulp_labels.



32
33
34
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 32

def pulp_labels
  @pulp_labels
end

#pulp_last_updatedObject

Timestamp of the last time this resource was updated. Note: for immutable resources - like content, repository versions, and publication - pulp_created and pulp_last_updated dates will be the same.



28
29
30
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 28

def pulp_last_updated
  @pulp_last_updated
end

#remoteObject

An optional remote to use by default when syncing.



49
50
51
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 49

def remote
  @remote
end

#repo_configObject

A JSON document describing the config.repo file Pulp should generate for this repo



85
86
87
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 85

def repo_config
  @repo_config
end

#repo_gpgcheckObject

REMOVED: An option specifying whether a client should perform a GPG signature check on the repodata. Not operational since pulp_rpm 3.30.0 release. Set these values using 'repo_config' instead.



79
80
81
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 79

def repo_gpgcheck
  @repo_gpgcheck
end

#retain_checkpointsObject

Retain X checkpoint publications for the repository. Default is null which retains all checkpoints.



46
47
48
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 46

def retain_checkpoints
  @retain_checkpoints
end

#retain_package_versionsObject

The number of versions of each package to keep in the repository; older versions will be purged. The default is '0', which will disable this feature and keep all versions of each package.



64
65
66
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 64

def retain_package_versions
  @retain_package_versions
end

#retain_repo_versionsObject

Retain X versions of the repository. Default is null which retains all versions.



43
44
45
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 43

def retain_repo_versions
  @retain_repo_versions
end

#sqlite_metadataObject

REMOVED: An option specifying whether Pulp should generate SQLite metadata. Not operation since pulp_rpm 3.25.0 release



82
83
84
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 82

def 
  @sqlite_metadata
end

#versions_hrefObject

Returns the value of attribute versions_href.



30
31
32
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 30

def versions_href
  @versions_href
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 555

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PulpRpmClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



152
153
154
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 152

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 119

def self.attribute_map
  {
    :'pulp_href' => :'pulp_href',
    :'prn' => :'prn',
    :'pulp_created' => :'pulp_created',
    :'pulp_last_updated' => :'pulp_last_updated',
    :'versions_href' => :'versions_href',
    :'pulp_labels' => :'pulp_labels',
    :'latest_version_href' => :'latest_version_href',
    :'name' => :'name',
    :'description' => :'description',
    :'retain_repo_versions' => :'retain_repo_versions',
    :'retain_checkpoints' => :'retain_checkpoints',
    :'remote' => :'remote',
    :'autopublish' => :'autopublish',
    :'metadata_signing_service' => :'metadata_signing_service',
    :'package_signing_service' => :'package_signing_service',
    :'package_signing_fingerprint' => :'package_signing_fingerprint',
    :'retain_package_versions' => :'retain_package_versions',
    :'checksum_type' => :'checksum_type',
    :'metadata_checksum_type' => :'metadata_checksum_type',
    :'package_checksum_type' => :'package_checksum_type',
    :'gpgcheck' => :'gpgcheck',
    :'repo_gpgcheck' => :'repo_gpgcheck',
    :'sqlite_metadata' => :'sqlite_metadata',
    :'repo_config' => :'repo_config',
    :'compression_type' => :'compression_type',
    :'layout' => :'layout',
    :'osv_config' => :'osv_config'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 531

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 190

def self.openapi_nullable
  Set.new([
    :'description',
    :'retain_repo_versions',
    :'retain_checkpoints',
    :'remote',
    :'metadata_signing_service',
    :'package_signing_service',
    :'package_signing_fingerprint',
    :'checksum_type',
    :'package_checksum_type',
    :'repo_config',
    :'compression_type',
    :'layout',
    :'osv_config'
  ])
end

.openapi_typesObject

Attribute type mapping.



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 157

def self.openapi_types
  {
    :'pulp_href' => :'String',
    :'prn' => :'String',
    :'pulp_created' => :'Time',
    :'pulp_last_updated' => :'Time',
    :'versions_href' => :'String',
    :'pulp_labels' => :'Hash<String, String>',
    :'latest_version_href' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'retain_repo_versions' => :'Integer',
    :'retain_checkpoints' => :'Integer',
    :'remote' => :'String',
    :'autopublish' => :'Boolean',
    :'metadata_signing_service' => :'String',
    :'package_signing_service' => :'String',
    :'package_signing_fingerprint' => :'String',
    :'retain_package_versions' => :'Integer',
    :'checksum_type' => :'PackageChecksumTypeEnum',
    :'metadata_checksum_type' => :'PackageChecksumTypeEnum',
    :'package_checksum_type' => :'PackageChecksumTypeEnum',
    :'gpgcheck' => :'Integer',
    :'repo_gpgcheck' => :'Integer',
    :'sqlite_metadata' => :'Boolean',
    :'repo_config' => :'Object',
    :'compression_type' => :'CompressionTypeEnum',
    :'layout' => :'LayoutEnum',
    :'osv_config' => :'Array<PatchedrpmRpmRepositoryOsvConfigInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 484

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pulp_href == o.pulp_href &&
      prn == o.prn &&
      pulp_created == o.pulp_created &&
      pulp_last_updated == o.pulp_last_updated &&
      versions_href == o.versions_href &&
      pulp_labels == o.pulp_labels &&
      latest_version_href == o.latest_version_href &&
      name == o.name &&
      description == o.description &&
      retain_repo_versions == o.retain_repo_versions &&
      retain_checkpoints == o.retain_checkpoints &&
      remote == o.remote &&
      autopublish == o.autopublish &&
       == o. &&
      package_signing_service == o.package_signing_service &&
      package_signing_fingerprint == o.package_signing_fingerprint &&
      retain_package_versions == o.retain_package_versions &&
      checksum_type == o.checksum_type &&
       == o. &&
      package_checksum_type == o.package_checksum_type &&
      gpgcheck == o.gpgcheck &&
      repo_gpgcheck == o.repo_gpgcheck &&
       == o. &&
      repo_config == o.repo_config &&
      compression_type == o.compression_type &&
      layout == o.layout &&
      osv_config == o.osv_config
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 626

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


518
519
520
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 518

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



524
525
526
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 524

def hash
  [pulp_href, prn, pulp_created, pulp_last_updated, versions_href, pulp_labels, latest_version_href, name, description, retain_repo_versions, retain_checkpoints, remote, autopublish, , package_signing_service, package_signing_fingerprint, retain_package_versions, checksum_type, , package_checksum_type, gpgcheck, repo_gpgcheck, , repo_config, compression_type, layout, osv_config].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 344

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if !@retain_repo_versions.nil? && @retain_repo_versions < 1
    invalid_properties.push('invalid value for "retain_repo_versions", must be greater than or equal to 1.')
  end

  if !@retain_checkpoints.nil? && @retain_checkpoints < 1
    invalid_properties.push('invalid value for "retain_checkpoints", must be greater than or equal to 1.')
  end

  if !@package_signing_fingerprint.nil? && @package_signing_fingerprint.to_s.length > 68
    invalid_properties.push('invalid value for "package_signing_fingerprint", the character length must be smaller than or equal to 68.')
  end

  if !@retain_package_versions.nil? && @retain_package_versions < 0
    invalid_properties.push('invalid value for "retain_package_versions", must be greater than or equal to 0.')
  end

  if !@gpgcheck.nil? && @gpgcheck > 1
    invalid_properties.push('invalid value for "gpgcheck", must be smaller than or equal to 1.')
  end

  if !@gpgcheck.nil? && @gpgcheck < 0
    invalid_properties.push('invalid value for "gpgcheck", must be greater than or equal to 0.')
  end

  if !@repo_gpgcheck.nil? && @repo_gpgcheck > 1
    invalid_properties.push('invalid value for "repo_gpgcheck", must be smaller than or equal to 1.')
  end

  if !@repo_gpgcheck.nil? && @repo_gpgcheck < 0
    invalid_properties.push('invalid value for "repo_gpgcheck", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



602
603
604
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 602

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



608
609
610
611
612
613
614
615
616
617
618
619
620
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 608

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



596
597
598
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 596

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/pulp_rpm_client/models/rpm_rpm_repository_response.rb', line 388

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if !@retain_repo_versions.nil? && @retain_repo_versions < 1
  return false if !@retain_checkpoints.nil? && @retain_checkpoints < 1
  return false if !@package_signing_fingerprint.nil? && @package_signing_fingerprint.to_s.length > 68
  return false if !@retain_package_versions.nil? && @retain_package_versions < 0
  return false if !@gpgcheck.nil? && @gpgcheck > 1
  return false if !@gpgcheck.nil? && @gpgcheck < 0
  return false if !@repo_gpgcheck.nil? && @repo_gpgcheck > 1
  return false if !@repo_gpgcheck.nil? && @repo_gpgcheck < 0
  true
end